@@ -1,9 +1,22 @@
 /*
+    This file is part of Photoflare.
 
-  Settings class for the PhotoFlare application.
+    Photoflare is free software: you can redistribute it and/or modify
+    it under the terms of the GNU General Public License as published by
+    the Free Software Foundation, either version 3 of the License, or
+    (at your option) any later version.
 
+    Photoflare is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+    GNU General Public License for more details.
+
+    You should have received a copy of the GNU General Public License
+    along with Photoflare.  If not, see <https://www.gnu.org/licenses/>.
 */
 
+// Settings class for the Photoflare application.
+
 #include <QSettings>
 #include <QRect>
 
@@ -27,6 +40,7 @@ public:
         compressionDefaultValue = settings.value("compressionDefaultValue").toString();
         historyLimit = settings.value("historyLimit").toString();
         dockLayout = settings.value("dockLayout").toString();
+        zoomDirection = settings.value("zoomDirection").toString();
         memDialogParams = settings.value("memorizeParamsEnabled").toBool();
         unit = settings.value("unit").toInt();
     }
@@ -58,6 +72,7 @@ public:
     QString compressionDefaultValue;
     QString historyLimit;
     QString dockLayout;
+    QString zoomDirection;
     bool memDialogParams;
     int unit;
     QSettings settings;
@@ -97,7 +112,8 @@ void Settings::setDefaultSettings()
     d->setValue("compressionDefaultEnabled", false);
     d->setValue("compressionDefaultValue", 90);
     d->setValue("compressionDialogEnabled", true);
-    d->setValue("dockLayout", "Right");
+    d->setValue("dockLayout", "0");
+    d->setValue("zoomDirection", "0");
     d->setValue("historyLimit", 24);
     d->setValue("memorizeParamsEnabled", true);
     d->setValue("prevOpened", false);
@@ -302,6 +318,17 @@ QString Settings::getDockLayout() const
     return d->dockLayout;
 }
 
+void Settings::setZoomDirection(const QString val)
+{
+    d->zoomDirection = val;
+    d->setValue("zoomDirection",val);
+}
+
+QString Settings::getZoomDirection() const
+{
+    return d->zoomDirection;
+}
+
 void Settings::setMemParamsEnabled(bool enabled)
 {
     d->memDialogParams = enabled;
