@@ -41,7 +41,7 @@ int main(int argc, char *argv[])
     {
         // App details
         app.setApplicationName("photoflare");
-        app.setApplicationVersion("1.6.6");
+        app.setApplicationVersion("1.6.9");
         app.setOrganizationDomain("photoflare.io");
 
         // Setup Default settings
@@ -108,6 +108,14 @@ int main(int argc, char *argv[])
             {
                 lang = "ru_RU";
             }
+            else if(sysLanguage == "Indonesian")
+            {
+                lang = "id";
+            }
+            else if(sysLanguage == "Spanish")
+            {
+                lang = "es";
+            }
             SETTINGS->setUserLanguage(lang);
         }
 
