@@ -31,6 +31,7 @@
 #include <QTimer>
 #include <QImageReader>
 #include <QInputDialog>
+#include <QSysInfo>
 
 #include "./tools/PaintBrushTool.h"
 #include "./tools/PaintBrushAdvTool.h"
@@ -247,7 +248,7 @@ void MainWindow::connectTools()
     QObject::connect(MOUSE_POINTER, SIGNAL(canvasSize()), this, SLOT(on_actionCanvas_Size_triggered()));
     QObject::connect(MOUSE_POINTER, SIGNAL(undo()), this, SLOT(on_actionUndo_triggered()));
     QObject::connect(MOUSE_POINTER, SIGNAL(redo()), this, SLOT(on_actionRedo_triggered()));
-    QObject::connect(MOUSE_POINTER, SIGNAL(showhotspots()), this, SLOT(on_show_hotspots_triggered()));
+    QObject::connect(MOUSE_POINTER, SIGNAL(showhotspots()), this, SLOT(onShowHotspotsTriggered()));
 
     // Setup signals for more Tools
     QObject::connect(COLOUR_PICKER, SIGNAL(pickPrimaryColor(const QPoint&)), this, SLOT(onPickPrimaryColor(const QPoint&)));
@@ -256,7 +257,7 @@ void MainWindow::connectTools()
     QObject::connect(PAINT_BUCKET, SIGNAL(floodFillPrimaryColor(const QPoint&)), this, SLOT(onFloodFillPrimaryColor(const QPoint&)));
     QObject::connect(PAINT_BUCKET, SIGNAL(floodFillSecondaryColor(const QPoint&)), this, SLOT(onFloodFillSecondaryColor(const QPoint&)));
 
-    QObject::connect(TEXT_TOOL, SIGNAL(editTextFinished()), this, SLOT(on_TextTool_finished()));
+    QObject::connect(TEXT_TOOL, SIGNAL(editTextFinished()), this, SLOT(onTextToolFinished()));
     QObject::connect(TEXT_TOOL, SIGNAL(editText(const QString&,const QFont&, const QColor&)), this, SLOT(onEditText(const QString&,const QFont&, const QColor&)));
 
     QObject::connect(MAGIC_WAND, SIGNAL(selectPrimaryColor(const QPoint&,int,bool)), this, SLOT(onSelectPrimaryColor(const QPoint&,int,bool)));
@@ -313,7 +314,7 @@ void MainWindow::addSettingsWidgets()
 
 */
 
-void MainWindow::on_image_filtered(QImage image)
+void MainWindow::onImageFiltered(QImage image)
 {
     PaintWidget *widget = getCurrentPaintWidget();
     if (widget)
@@ -336,7 +337,7 @@ void MainWindow::applyThreadedFilter(QString filterName, double dV)
     worker->moveToThread(thread);
 
     connect(thread, SIGNAL(started()), worker, SLOT(process()));
-    connect(worker, SIGNAL(filterProcessFinished(QImage)), this, SLOT(on_image_filtered(QImage)));
+    connect(worker, SIGNAL(filterProcessFinished(QImage)), this, SLOT(onImageFiltered(QImage)));
     thread->start();
 
     batchLbl->setText(tr("Working..."));
@@ -356,7 +357,7 @@ void MainWindow::applyThreadedFilterMP(QString filterName, double dV)
     worker->moveToThread(thread);
 
     connect(thread, SIGNAL(started()), worker, SLOT(process()));
-    connect(worker, SIGNAL(filterProcessFinished(QImage)), this, SLOT(on_image_filtered(QImage)));
+    connect(worker, SIGNAL(filterProcessFinished(QImage)), this, SLOT(onImageFiltered(QImage)));
     thread->start();
 
     batchLbl->setText(tr("Working..."));
@@ -388,13 +389,18 @@ void MainWindow::on_actionOpen_triggered()
 {
     const QStringList& fileName = QFileDialog::getOpenFileNames(this, tr("Open File"),
     SETTINGS->getOpenFolder(),
-    tr("Image Files")+"(*.png *.PNG *.jpg *.jpeg *.JPG *.JPEG *.gif *.GIF *.tif *.tiff *.TIF *.TIFF *.bmp *.BMP *.ico *.ICO);;"
+    tr("Image Files")+
+    "(*.png *.PNG *.jpg *.jpeg *.JPG *.JPEG *.gif *.GIF *.tif *.tiff *.TIF *.TIFF *.bmp *.BMP *.ico *.ICO *.pbm *.PBM *.pgm *.PGM *.ppm *.PPM);;"
+
     "PNG(*.png *.PNG);;"
     "JPEG(*.jpg *.jpeg *.JPG *.JPEG);;"
     "GIF(*.gif *.GIF);;"
     "TIFF(*.tif *.tiff *.TIF *.TIFF);;"
     "BMP(*.bmp *.BMP);;"
     "ICO(*.ico *.ICO);;"
+    "PBM(*.pbm *.PBM);;"
+    "PGM(*.pgm *.PGM);;"
+    "PPM(*.ppm *.PPM);;"
     +tr("All Files")+"(*)");
 /*
  *  Previously supported RAW formats
@@ -443,26 +449,7 @@ QString MainWindow::prepareFile(const QString& fileName)
     QImageReader reader(fileName);
     reader.setDecideFormatFromContent(true); // Autodetect file type without depending on extension
 
-    // Show warning if file type is supported but extension does not match
-    if(info.completeSuffix().toLower() != "jpg" && info.completeSuffix().toLower() != reader.format() && fileTypeSupported(reader.supportedImageFormats(),reader.format()))
-    {
-        int ret = QMessageBox::warning(this,
-                    tr("Incorrect file extension detected"),
-                    tr("Do you want to update this extension?"),
-                    QMessageBox::Save,QMessageBox::Cancel);
-
-        if(ret == QMessageBox::Save)
-        {
-          newFileName = info.path()+QDir::separator()+info.baseName()+"."+reader.format();
-          QDir dir (info.baseName());
-          dir.rename(fileName,newFileName);
-        }
-        else if(ret == QMessageBox::Cancel)
-        {
-            newFileName = "";
-        }
-    }
-    else if(!fileTypeSupported(reader.supportedImageFormats(),reader.format()))
+    if(!fileTypeSupported(reader.supportedImageFormats(),reader.format()))
     {
         newFileName = "";
         showError(tr("Please open a valid image file"));
@@ -715,6 +702,9 @@ void MainWindow::on_actionImage_properties_triggered()
             dialog.setFolder(fileInfo.path());
             dialog.setFileSize(fileInfo.size());
             dialog.setDate(QString("%1").arg(fileInfo.lastModified().toString("dd/MM/yyyy hh:mm")));
+
+            QImageReader reader(widget->imagePath());
+            dialog.setFileType(reader.format());
         }
         dialog.setColorCount(widget->image());
         dialog.setSize(widget->image().size());
@@ -1061,7 +1051,7 @@ void MainWindow::onPreviewTransparent(QColor color, int tolerance)
         widget->setImageOriginal(FilterManager::instance()->floodFillOpacity(origImage, color, tolerance));
 }
 
-void MainWindow::on_TextTool_finished()
+void MainWindow::onTextToolFinished()
 {
     m_toolSelected = m_previousToolSelected;
     QTimer::singleShot(1000, this, SLOT(refreshTools()));
@@ -1128,6 +1118,7 @@ void MainWindow::on_actionSelect_all_triggered()
 void MainWindow::onSelectionChanged(bool visible)
 {
     ui->actionCrop->setEnabled(ui->actionShow_selection->isChecked() && visible);
+    ui->actionShow_selection->setChecked(visible);
 }
 
 /*
@@ -1198,7 +1189,7 @@ void MainWindow::on_actionOpacity_triggered()
     {
         bool ok;
         double d = QInputDialog::getDouble(this, tr("Set Image Opacity"),
-                                               tr("Opacity:"), 0.5, 0.0, 1.0, 2, &ok);
+                                               tr("Opacity:"), 0.5, 0.0, 1.0, 2, &ok, Qt::WindowFlags(), 0.1);
         if(ok)
         {
             applyThreadedFilter("setOpacity", d);
@@ -1244,7 +1235,16 @@ void MainWindow::on_actionDustReduction_triggered()
 {
     PaintWidget *widget = getCurrentPaintWidget();
     if (widget)
-    applyThreadedFilterMP("dustreduction");
+    {
+        if(QSysInfo::productType() == "windows")
+        {
+            applyThreadedFilter("dustreduction");
+        }
+        else
+        {
+            applyThreadedFilterMP("dustreduction");
+        }
+    }
 }
 
 void MainWindow::on_actionDespeckle_triggered()
@@ -1265,21 +1265,48 @@ void MainWindow::on_actionImpulse_triggered()
 {
     PaintWidget *widget = getCurrentPaintWidget();
     if (widget)
-    applyThreadedFilterMP("impulseNoise");
+    {
+        if(QSysInfo::productType() == "windows")
+        {
+            applyThreadedFilter("impulseNoise");
+        }
+        else
+        {
+            applyThreadedFilterMP("impulseNoise");
+        }
+    }
 }
 
 void MainWindow::on_actionLaplacian_triggered()
 {
     PaintWidget *widget = getCurrentPaintWidget();
     if (widget)
-    applyThreadedFilterMP("laplacianNoise");
+    {
+        if(QSysInfo::productType() == "windows")
+        {
+            applyThreadedFilter("laplacianNoise");
+        }
+        else
+        {
+            applyThreadedFilterMP("laplacianNoise");
+        }
+    }
 }
 
 void MainWindow::on_actionPoisson_triggered()
 {
     PaintWidget *widget = getCurrentPaintWidget();
     if (widget)
-    applyThreadedFilterMP("poissonNoise");
+    {
+        if(QSysInfo::productType() == "windows")
+        {
+            applyThreadedFilter("poissonNoise");
+        }
+        else
+        {
+            applyThreadedFilterMP("poissonNoise");
+        }
+    }
 }
 
 void MainWindow::on_actionGrayScale_triggered()
@@ -1335,7 +1362,16 @@ void MainWindow::on_actionOil_Paint_triggered()
 {
     PaintWidget *widget = getCurrentPaintWidget();
     if (widget)
-    applyThreadedFilterMP("oil");
+    {
+        if(QSysInfo::productType() == "windows")
+        {
+            applyThreadedFilter("oil");
+        }
+        else
+        {
+            applyThreadedFilterMP("oil");
+        }
+    }
 }
 
 void MainWindow::on_actionCharcoal_Drawing_triggered()
@@ -1445,10 +1481,12 @@ void MainWindow::on_actionToolpalette_triggered()
     if(ui->dockWidget_palette->isVisible())
     {
         ui->dockWidget_palette->hide();
+        ui->dockWidgetSettings->hide();
     }
     else
     {
         ui->dockWidget_palette->show();
+        ui->dockWidgetSettings->show();
     }
 }
 
@@ -1825,15 +1863,18 @@ void MainWindow::onPickPrimaryColor(const QPoint& pos)
     if(widget)
     {
         const QImage& image = widget->image();
-        const QColor& color = image.pixel(pos);
-
-        if(transparentDialog)
+        // Make sure we are inside the image area
+        if(pos.x() >= 0 && pos.x() < image.width() && pos.y() >= 0 && pos.y() < image.height())
         {
-            transparentDialog->setColor(color.rgb());
-        }
-        else
-        {
-            ui->colorBoxWidget->setPrimaryColor(color);
+            const QColor& color = image.pixel(pos);
+            if(transparentDialog)
+            {
+                transparentDialog->setColor(color.rgb());
+            }
+            else
+            {
+                ui->colorBoxWidget->setPrimaryColor(color);
+            }
         }
     }
 }
@@ -1844,9 +1885,12 @@ void MainWindow::onPickSecondaryColor(const QPoint& pos)
     if(widget)
     {
         const QImage& image = widget->image();
-        const QColor& color = image.pixel(pos);
-
-        ui->colorBoxWidget->setSecondaryColor(color);
+        // Make sure we are inside the image area
+        if(pos.x() >= 0 && pos.x() < image.width() && pos.y() >= 0 && pos.y() < image.height())
+        {
+            const QColor& color = image.pixel(pos);
+            ui->colorBoxWidget->setSecondaryColor(color);
+        }
     }
 }
 
@@ -2366,7 +2410,7 @@ PaintWidget* MainWindow::getCurrentPaintWidget()
     return widget;
 }
 
-void MainWindow::on_show_hotspots_triggered()
+void MainWindow::onShowHotspotsTriggered()
 {
     PaintWidget *widget = getCurrentPaintWidget();
     if (widget)
@@ -2405,43 +2449,98 @@ void MainWindow::on_actionBrightminus_triggered()
 void MainWindow::on_actionContrastplus_triggered()
 {
     PaintWidget *widget = getCurrentPaintWidget();
+
     if (widget)
-        applyThreadedFilterMP("contrastplus");
+    {
+        if(QSysInfo::productType() == "windows")
+        {
+            applyThreadedFilter("contrastplus");
+        }
+        else
+        {
+            applyThreadedFilterMP("contrastplus");
+        }
+    }
 }
 
 void MainWindow::on_actionContrastminus_triggered()
 {
     PaintWidget *widget = getCurrentPaintWidget();
     if (widget)
-        applyThreadedFilterMP("contrastminus");
+    {
+        if(QSysInfo::productType() == "windows")
+        {
+            applyThreadedFilter("contrastminus");
+        }
+        else
+        {
+            applyThreadedFilterMP("contrastminus");
+        }
+    }
 }
 
 void MainWindow::on_actionSaturationplus_triggered()
 {
     PaintWidget *widget = getCurrentPaintWidget();
     if (widget)
-        applyThreadedFilterMP("saturationplus");
+    {
+        if(QSysInfo::productType() == "windows")
+        {
+            applyThreadedFilter("saturationplus");
+        }
+        else
+        {
+            applyThreadedFilterMP("saturationplus");
+        }
+    }
 }
 
 void MainWindow::on_actionSaturationminus_triggered()
 {
     PaintWidget *widget = getCurrentPaintWidget();
     if (widget)
-        applyThreadedFilterMP("saturationminus");
+    {
+        if(QSysInfo::productType() == "windows")
+        {
+            applyThreadedFilter("saturationminus");
+        }
+        else
+        {
+            applyThreadedFilterMP("saturationminus");
+        }
+    }
 }
 
 void MainWindow::on_actionGammaCorrectplus_triggered()
 {
     PaintWidget *widget = getCurrentPaintWidget();
     if (widget)
-        applyThreadedFilterMP("gammacorrectplus");
+    {
+        if(QSysInfo::productType() == "windows")
+        {
+            applyThreadedFilter("gammacorrectplus");
+        }
+        else
+        {
+            applyThreadedFilterMP("gammacorrectplus");
+        }
+    }
 }
 
 void MainWindow::on_actionGammaCorrectminus_triggered()
 {
     PaintWidget *widget = getCurrentPaintWidget();
     if (widget)
-        applyThreadedFilterMP("gammacorrectminus");
+    {
+        if(QSysInfo::productType() == "windows")
+        {
+            applyThreadedFilter("gammacorrectminus");
+        }
+        else
+        {
+            applyThreadedFilterMP("gammacorrectminus");
+        }
+    }
 }
 
 void MainWindow::on_actionGradient_triggered()
