@@ -55,26 +55,6 @@ public:
     }
 
     QImage toQtImage(Magick::Image *image)
-    {
-        int imagecols = image->columns();
-        int imagerows = image->rows();
-
-        QImage newQImage = QImage(imagecols, imagerows, QImage::Format_RGB32);
-        const Magick::PixelPacket *pixels;
-        Magick::ColorRGB rgb;
-        for (int y = 0; y < newQImage.height(); y++)
-        {
-            pixels = image->getConstPixels(0, y, newQImage.width(), 1);
-            for (int x = 0; x < newQImage.width(); x++)
-            {
-                rgb = (*(pixels + x));
-                newQImage.setPixel(x, y, QColor((int)(255 * rgb.red()), (int)(255 * rgb.green()), (int)(255 * rgb.blue())).rgb());
-            }
-        }
-        return newQImage;
-    }
-
-    QImage toQtImageTransparent(Magick::Image *image)
     {
         Magick::Blob blob;
         image->write(&blob);
@@ -184,7 +164,7 @@ QImage FilterManager::blackwhite(const QImage &image)
 QImage FilterManager::colourthreshold(const QImage &image)
 {
     Magick::Image *magickImage = d->fromQtImage(image);
-    magickImage->adaptiveThreshold(400,300);
+    magickImage->adaptiveThreshold(image.width(),image.height());
 
     QImage modifiedImage = d->toQtImage(magickImage);
     delete magickImage;
@@ -771,7 +751,7 @@ QImage FilterManager::floodFillOpacity(const QImage &image, const QColor &color,
             }
         }
     }
-    return d->toQtImageTransparent(magickImage.data());
+    return d->toQtImage(magickImage.data());
 }
 
 FilterManager::FilterManager()
