@@ -34,8 +34,9 @@ class QProgressIndicator : public QWidget
     Q_PROPERTY(int delay READ animationDelay WRITE setAnimationDelay)
     Q_PROPERTY(bool displayedWhenStopped READ isDisplayedWhenStopped WRITE setDisplayedWhenStopped)
     Q_PROPERTY(QColor color READ color WRITE setColor)
+
 public:
-    QProgressIndicator(QWidget* parent = 0);
+    QProgressIndicator(QWidget* parent = nullptr);
 
     /*! Returns the delay between animation steps.
         \return The number of milliseconds between animation steps. By default, the animation delay is set to 40 milliseconds.
@@ -62,6 +63,7 @@ public:
 
     virtual QSize sizeHint() const;
     int heightForWidth(int w) const;
+
 public slots:
     /*! Starts the spin animation.
         \sa stopAnimation isAnimated
@@ -95,9 +97,11 @@ public slots:
         \sa color
      */
     void setSize(const QSize& size);
+
 protected:
     virtual void timerEvent(QTimerEvent * event); 
     virtual void paintEvent(QPaintEvent * event);
+
 private:
     int m_angle;
     int m_timerId;
