@@ -27,12 +27,16 @@ class EraserTool : public Tool
 public:
     EraserTool(QObject *parent = nullptr);
     ~EraserTool() override;
+
     void setWidth(int width);
     int width() const;
     void onMousePress(const QPoint &pos, Qt::MouseButton button) override;
     void onMouseMove(const QPoint &pos) override;
     QCursor getCursor() override;
 
+public slots:
+    void setSecondaryColor(const QColor &color);
+
 private:
     EraserToolPrivate *d;
 };
