@@ -25,6 +25,7 @@
 #include <QGraphicsScene>
 #include <QGraphicsSceneMouseEvent>
 #include <QGraphicsProxyWidget>
+#include <QGraphicsEffect>
 #include <QImageReader>
 
 #include "../Settings.h"
@@ -56,7 +57,12 @@ public:
         this->image = image;
         q->setSceneRect(image.rect());
         canvas = addPixmap(QPixmap::fromImage(image));
-        q->setStyleSheet("background-color: rgb(128, 128, 128);");
+        q->setStyleSheet("background-color: rgb(160, 160, 160);");
+
+        // Canvas drop shadow to separate from MdiArea colour
+        QGraphicsDropShadowEffect* effect = new QGraphicsDropShadowEffect();
+        effect->setBlurRadius(15);
+        canvas->setGraphicsEffect(effect);
     }
 
     void updateImageCanvas()
