@@ -27,17 +27,18 @@ class BatchProcessWorker : public QObject
 {
     Q_OBJECT
 public:
-    explicit BatchProcessWorker(QObject *parent = 0);
+    explicit BatchProcessWorker(QObject *parent = nullptr);
 
     void setParams(batchDialog* params){m_params = params;}
     void setParent(MainWindow* parent){m_parent = parent;}
+
 public slots:
     void process();
 
 signals:
-
     void fileProcessFinished(QString file, QImage image);
     void batchProgress(int idx, int total);
+
 private:
     batchDialog* m_params;
     MainWindow* m_parent;
